@@ -4,7 +4,8 @@ from __future__ import annotations
 
 def process_woplugmini(data: bytes, mfr_data: bytes | None) -> dict[str, bool | int]:
     """Process plug mini."""
-    assert mfr_data is not None
+    if mfr_data is None:
+        return {}
     return {
         "switchMode": True,
         "isOn": mfr_data[7] == 0x80,
